import os
from PyPDF2 import PdfReader, PdfWriter
from statistics import mean

def remove_wide_pages(input_pdf, threshold=1.6):
    try:
        reader = PdfReader(input_pdf)
        writer = PdfWriter()

        # Calculate the average width of all pages
        widths = []
        for page in reader.pages:
            try:
                widths.append(float(page.mediabox.width))
            except (ValueError, TypeError):
                print(f"Warning: Could not determine width for a page in {input_pdf}")
                continue

        if not widths:
            print(f"Error: Could not determine any valid page widths in {input_pdf}")
            return

        avg_width = mean(widths)

        # Remove pages that are wider than the threshold
        for i, page in enumerate(reader.pages):
            try:
                if float(page.mediabox.width) <= avg_width * threshold:
                    writer.add_page(page)
                else:
                    print(f"Removing page {i+1} (width: {page.mediabox.width}) from {input_pdf}")
            except (ValueError, TypeError):
                print(f"Warning: Could not process page {i+1} in {input_pdf}")
                writer.add_page(page)  # Keep the page if we can't determine its width

        # Overwrite the original PDF
        with open(input_pdf, "wb") as output_file:
            writer.write(output_file)

        print(f"Processed: {input_pdf}")
    except Exception as e:
        print(f"Error processing {input_pdf}: {str(e)}")

def process_pdfs_in_directory(directory):
    for root, dirs, files in os.walk(directory):
        for file in files:
            if file.lower().endswith('.pdf'):
                pdf_path = os.path.join(root, file)
                remove_wide_pages(pdf_path)

if __name__ == "__main__":
    current_directory = os.getcwd()
    process_pdfs_in_directory(current_directory)
    print("All PDFs have been processed.")